@@ -1,14 +1,13 @@
-import sys
+"""Module providing models functionality."""
 
+import sys
+from datetime import datetime, timedelta
 import requests
 
 from matrice.dataset import Dataset
-import matplotlib.pyplot as plt
-import seaborn as sns
-from datetime import datetime, timedelta
-
 from matrice.utils import handle_response
 
+
 class Model:
     """
     The `Model` class provides methods for interacting with models in a project,
@@ -29,7 +28,13 @@ class Model:
     >>> model = Model(session, model_id="model789")
     """
 
-    def __init__(self, session, model_id=None, model_name=""):
+    def __init__(
+        self,
+        session,
+        model_id=None,
+        model_name="",
+    ):
+        """Initialize Model class."""
         self.session = session
         self.project_id = session.project_id
         self.last_refresh_time = datetime.now()
@@ -37,14 +42,11 @@ class Model:
         self.model_id = model_id
         self.model_name = model_name
         self.rpc = session.rpc
-       
-        # Model Train Details
-        details_response , err , msg = self.get_details()
+        details_response, _, _ = self.get_details()
         self.details = details_response
         self.model_id = details_response.get("_id")
         self.dataset_id = details_response.get("_idDataset")
-        self.model_info_id = details_response.get("_idModelInfo")
-        self.experiment_id = details_response.get("_idExperiment")
+        self.model_arch_id = details_response.get("_idModelArch")
         self.action_status_id = details_response.get("_idActionStatus")
         self.model_family_id = details_response.get("_idModelFamily")
         self.project_id = details_response.get("_idProject")
@@ -53,7 +55,7 @@ class Model:
         self.model_key = details_response.get("modelKey")
         self.model_family_name = details_response.get("modelName")
         self.auto_ml = details_response.get("autoML")
-        self.params_millions = details_response.get("paramsMillions")
+        self.params_millions = details_response.get("paramsInMillion")
         self.tuning_type = details_response.get("tuningType")
         self.training_framework = details_response.get("trainingFramework")
         self.model_checkpoint = details_response.get("modelCheckpoint")
@@ -65,7 +67,7 @@ class Model:
         self.status = details_response.get("status")
         self.dataset_version = details_response.get("datasetVersion")
         self.model_inputs = details_response.get("modelInputs", [])
-        self.model_outputs = details_response.get("modelOutputs", [])      
+        self.model_outputs = details_response.get("modelOutputs", [])
         self.target_runtime = details_response.get("targetRuntime", [])
         self.action_config = details_response.get("actionConfig", {})
         self.model_config = details_response.get("modelConfig", {})
@@ -75,35 +77,24 @@ class Model:
         self.index_to_cat = details_response.get("indexToCat", {})
         self.best_epoch = details_response.get("bestEpoch")
         self.cloud_path = details_response.get("cloudPath")
-        self.experiment_name = details_response.get("experimentName")
         self.created_at = details_response.get("createdAt")
         self.updated_at = details_response.get("updatedAt")
-        self.architecture=details_response.get("modelKey")
-        
+        self.architecture = details_response.get("modelKey")
+
     def refresh(self):
-        """
-        Refresh the instance by reinstantiating it with the previous values.
-        """
-        # Check if two minutes have passed since the last refresh
+        """Refresh the instance by reinstantiating it with the previous values."""
         if datetime.now() - self.last_refresh_time < timedelta(minutes=2):
-            raise Exception("Refresh can only be called after two minutes since the last refresh.")
-
-        # Capture the current state
-        state = self.__dict__.copy()
-
+            raise ValueError(
+                "Refresh can only be called after two minutes since the last refresh."
+            )
+        self.__dict__.copy()
         init_params = {
-            'session': self.session,
-            'model_name': self.model_name,
+            "session": self.session,
+            "model_name": self.model_name,
         }
-
-        # Reinitialize the instance
         self.__init__(**init_params)
-
-        # Update the last refresh time
         self.last_refresh_time = datetime.now()
 
-
-
     def get_details(self):
         """
         Get model details based on the provided ID or name.
@@ -121,23 +112,21 @@ class Model:
         >>> else:
         >>>     print(f"Model details: {details}")
         """
-        id = self.model_id
+        model_id = self.model_id
         name = self.model_name
-
-        if id:
+        if model_id:
             try:
                 return self._get_model_train_by_id()
-            except Exception as e:
-                print(f"Error retrieving model train by id: {e}")
+            except Exception as err:
+                print(f"Error retrieving model train by id: {err}")
         elif name:
             try:
                 return self._get_model_train_by_name()
-            except Exception as e:
-                print(f"Error retrieving model train by name: {e}")
+            except Exception as err:
+                print(f"Error retrieving model train by name: {err}")
         else:
-            raise ValueError(
-                "At least one of 'model_id' or 'model_name' must be provided."
-            )
+            raise ValueError("At least one of 'model_id' or 'model_name' must be provided.")
+        return None, None, None
 
     def rename(self, name):
         """
@@ -164,12 +153,17 @@ class Model:
         if self.model_id is None:
             print("Set Model Id for model object")
             sys.exit(0)
-
         path = f"/v1/model/{self.model_id}/update_modelTrain_name"
         headers = {"Content-Type": "application/json"}
-        model_payload = {"modelTrainId": self.model_id, "name": name}
-        resp = self.rpc.put(path=path, headers=headers, payload=model_payload)
-
+        model_payload = {
+            "modelTrainId": self.model_id,
+            "name": name,
+        }
+        resp = self.rpc.put(
+            path=path,
+            headers=headers,
+            payload=model_payload,
+        )
         return handle_response(
             resp,
             "Model train name updated successfully",
@@ -198,19 +192,20 @@ class Model:
             sys.exit(0)
         path = f"/v1/model/delete_model_train/{self.model_id}"
         resp = self.rpc.delete(path=path)
-
         return handle_response(
-            resp, "Model train deleted successfully", "Could not delete model train"
+            resp,
+            "Model train deleted successfully",
+            "Could not delete model train",
         )
 
-    def get_prediction(self, image_path):
+    def get_prediction(self, input_path):
         """
         Tests a trained model for a given image.
 
         Parameters:
         -----------
-        image_path : str
-            The path to the image for testing.
+        input_path : str
+            The path to the input for testing.
 
         Returns:
         --------
@@ -223,21 +218,27 @@ class Model:
         >>> print(result)
         {'test_result': 'success', 'confidence': 0.85}
         """
-        files = {"image": open(image_path, "rb")}
+        with open(input_path, "rb") as input_file:
+            files = {"input": input_file}
+            url = f"/v1/model_prediction/model_test/{self.model_id}?projectId={self.project_id}"
+            resp = self.rpc.post(url, files=files)
+            success_message = "Model test completed successfully"
+            error_message = "An error occurred while testing the model."
+            return handle_response(
+                resp,
+                success_message,
+                error_message,
+            )
 
-        # Model testing
-        url = f"/v1/model_prediction/model_test/{self.model_id}?projectId={self.project_id}"
-        resp = self.rpc.post(url, files=files)
-        success_message = "Model test completed successfully"
-        error_message = "An error occurred while testing the model."
-
-        return handle_response(resp, success_message, error_message)
-
-        
-        
-    def get_eval_result(self, dataset_id, dataset_version, split_type):
+    def get_eval_result(
+        self,
+        dataset_id,
+        dataset_version,
+        split_type,
+    ):
         """
-        Fetch the evaluation result of a trained model using a specific dataset version and split type.
+        Fetch the evaluation result of a trained model using a specific dataset version and split
+            type.
 
         Parameters
         ----------
@@ -261,30 +262,25 @@ class Model:
         >>> else:
         >>>     print(f"Evaluation result: {eval_result}")
         """
-
-        D = Dataset(self.session, dataset_id)
-        dataset_info, _, _ = D.get_processed_versions()
+        dataset = Dataset(self.session, dataset_id)
+        dataset_info, _, _ = dataset.get_processed_versions()
         if dataset_info is None:
             print("No datasets found")
             sys.exit(0)
-
         flag = False
         for data_info in dataset_info:
             if dataset_id == data_info["_id"]:
                 if dataset_version in data_info["processedVersions"]:
                     flag = True
                     break
-
-        if flag == False:
+        if not flag:
             print(
                 "Dataset or Dataset version does not exist. Can not use this dataset version to get/create a eval."
             )
             sys.exit(0)
-
         if self.model_id is None:
             print("Model Id is required for this operation")
             sys.exit(0)
-
         path = "/v1/model/get_eval_result"
         headers = {"Content-Type": "application/json"}
         model_payload = {
@@ -293,8 +289,11 @@ class Model:
             "datasetVersion": dataset_version,
             "splitType": split_type,
         }
-        resp = self.rpc.post(path=path, headers=headers, payload=model_payload)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=model_payload,
+        )
         return handle_response(
             resp,
             "Eval result fetched successfully",
@@ -318,22 +317,13 @@ class Model:
             dataset_version=self.dataset_version,
             split_type=["train", "val", "test"],
         )[0]
-        df = pd.DataFrame(eval_result)
-        # Set up the figure
+        df_results = pd.DataFrame(eval_result)
         plt.figure(figsize=(14, 12))
-
-        # List of unique metrics
-        metrics = df["metricName"].unique()
+        metrics = df_results["metricName"].unique()
         num_metrics = len(metrics)
-
-        # Loop through each metric and create a horizontal bar plot
         for i, metric in enumerate(metrics, 1):
             plt.subplot((num_metrics + 1) // 2, 2, i)
-
-            # Filter data for the current metric
-            metric_data = df[df["metricName"] == metric]
-
-            # Create horizontal bar plot
+            metric_data = df_results[df_results["metricName"] == metric]
             sns.barplot(
                 data=metric_data,
                 x="metricValue",
@@ -341,12 +331,9 @@ class Model:
                 hue="category",
                 orient="h",
             )
-
-            # Set titles and labels
             plt.xlabel(metric)
-            plt.xlim(0, 1)  # Assuming metric values are between 0 and 1
+            plt.xlim(0, 1)
             plt.legend(title="Category")
-
         plt.tight_layout()
         plt.show()
 
@@ -369,7 +356,6 @@ class Model:
         """
         path = f"/v1/model/model_train/{self.model_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             "Model train by ID fetched successfully",
@@ -393,14 +379,13 @@ class Model:
         >>> else:
         >>>     print(f"Model data: {model_data}")
         """
-        if self.model_name == "":
+        if not self.model_name:
             print(
                 "Model name not set for this Model train. Cannot perform the operation for Model without model name"
             )
             sys.exit(0)
         path = f"/v1/model/model_train/get_model_train_by_name?modelTrainName={self.model_name}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             "Model train by name fetched successfully",
@@ -447,8 +432,7 @@ class Model:
         if self.model_id is None:
             print("Set Model Id for model object")
             sys.exit(0)
-
-        model_by_id_resp, _, _ = self._get_model_train_by_id()
+        _, _, _ = self._get_model_train_by_id()
         path = "/v1/model/add_model_eval"
         headers = {"Content-Type": "application/json"}
         model_payload = {
@@ -458,25 +442,27 @@ class Model:
             "isPruned": is_pruned,
             "runtimeFramework": "Pytorch",
             "_idDataset": dataset_id,
-            "_idExperiment": model_by_id_resp["_idExperiment"],
             "datasetVersion": dataset_version,
             "gpuRequired": is_gpu_required,
             "splitTypes": split_types,
             "modelType": "trained",
             "exportFormat": None,
         }
-        resp = self.rpc.post(path=path, headers=headers, payload=model_payload)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=model_payload,
+        )
         return handle_response(
             resp,
             "Model eval added successfully",
             "An error occurred while adding model eval",
         )
 
-    
     def get_download_path(self):
         """
-        Get the download path for the specified model type. There are 2 types of model types: trained and exported.
+        Get the download path for the specified model type. There are 2 types of model types:
+            trained and exported.
 
         Parameters
         ----------
@@ -501,7 +487,6 @@ class Model:
                 "Model id not set for this model. Cannot perform the operation for model without model id"
             )
             sys.exit(0)
-
         path = "/v1/model/get_model_download_path"
         headers = {"Content-Type": "application/json"}
         model_payload = {
@@ -509,18 +494,21 @@ class Model:
             "modelType": "trained",
             "expiryTimeInMinutes": 15,
         }
-        resp = self.rpc.post(path=path, headers=headers, payload=model_payload)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=model_payload,
+        )
         return handle_response(
             resp,
             "Model download path fetched successfully and it will expire in 15 mins",
             "An error occured while downloading the model",
         )
 
-    
     def download_model(self, file_name):
         """
-        Download the specified model type to a local file. There are 2 types of model types: trained and exported.
+        Download the specified model type to a local file. There are 2 types of model types:
+            trained and exported.
 
         Parameters
         ----------
@@ -543,28 +531,23 @@ class Model:
         >>> else:
         >>>     print(f"Model downloaded: {result}")
         """
-        
         presigned_url = self.rpc.post(
-                path=f"/v1/model/get_model_download_path",
-                payload={
-                    "modelID": self.model_id,
-                    "modelType": "trained",
-                    "expiryTimeInMinutes": 59,
-                },
-            )["data"]
-
-
-        response = requests.get(presigned_url)
-
+            path="/v1/model/get_model_download_path",
+            payload={
+                "modelID": self.model_id,
+                "modelType": "trained",
+                "expiryTimeInMinutes": 59,
+            },
+        )["data"]
+        response = requests.get(presigned_url, timeout=30)
         if response.status_code == 200:
             with open(file_name, "wb") as file:
                 file.write(response.content)
             print("Model downloaded successfully")
             return file_name
-        else:
-            print(f"Model download failed with status code: {response.status_code}")
-            return ""
-    
+        print(f"Model download failed with status code: {response.status_code}")
+        return ""
+
     def get_model_training_logs(self):
         """
         Fetch training logs for the specified model.
@@ -596,14 +579,13 @@ class Model:
         else:
             error = resp.get("message")
             message = "Failed to fetch model logs."
-
         return resp, error, message
 
     def plot_epochs_losses(self):
         """
         Plot training and validation losses over epochs.
 
-        This method generates two subplots: one for the training losses and one for 
+        This method generates two subplots: one for the training losses and one for
         the validation losses, displaying how these metrics evolve over the epochs.
 
         Returns
@@ -614,9 +596,11 @@ class Model:
         -------
         >>> model_logging.plot_epochs_losses()
         """
-        resp, error, message = self.get_model_training_logs()
-        training_logs = resp["data"]
+        import matplotlib.pyplot as plt
+        import seaborn as sns
 
+        resp, _, _ = self.get_model_training_logs()
+        training_logs = resp["data"]
         epochs = []
         metrics = {"train": {}, "val": {}}
         for epoch_data in training_logs:
@@ -625,22 +609,19 @@ class Model:
                 metric_name = detail["metricName"]
                 metric_value = detail["metricValue"]
                 split_type = detail["splitType"]
-
                 if "loss" in metric_name:
                     if split_type not in metrics:
                         metrics[split_type] = []
                     if metric_name not in metrics[split_type]:
                         metrics[split_type][metric_name] = []
                     metrics[split_type][metric_name].append(metric_value)
-
-        # Set plot style
         sns.set(style="whitegrid")
-        # Create figure and axes
         fig, axs = plt.subplots(2, 1, figsize=(12, 18))
-        
-        # Plot training losses
-        for split_type, split_metrics in metrics.items():
-            for metric_name in split_metrics.keys():
+        for (
+            split_type,
+            split_metrics,
+        ) in metrics.items():
+            for metric_name in split_metrics:
                 if split_type == "train":
                     axs[0].plot(
                         epochs,
@@ -653,20 +634,22 @@ class Model:
                         split_metrics[metric_name],
                         label=f"{split_type} {metric_name}",
                     )
-
-        # Set labels and titles
         axs[0].set_xlabel("Epoch", fontsize=14)
         axs[0].set_ylabel("Loss", fontsize=14)
         axs[0].legend(fontsize=12)
-        axs[0].set_title("Training Losses over Epochs", fontsize=16)
+        axs[0].set_title(
+            "Training Losses over Epochs",
+            fontsize=16,
+        )
         axs[0].grid(True)
-
         axs[1].set_xlabel("Epoch", fontsize=14)
         axs[1].set_ylabel("Loss", fontsize=14)
         axs[1].legend(fontsize=12)
-        axs[1].set_title("Validation Losses over Epochs", fontsize=16)
+        axs[1].set_title(
+            "Validation Losses over Epochs",
+            fontsize=16,
+        )
         axs[1].grid(True)
-
         plt.tight_layout()
         plt.show()
 
@@ -674,8 +657,8 @@ class Model:
         """
         Plot training and validation metrics (excluding losses) over epochs.
 
-        This method generates subplots for each non-loss metric, such as accuracy, 
-        showing how these metrics change during training epochs for both training 
+        This method generates subplots for each non-loss metric, such as accuracy,
+        showing how these metrics change during training epochs for both training
         and validation splits.
 
         Returns
@@ -686,21 +669,20 @@ class Model:
         -------
         >>> model_logging.plot_epochs_metrics()
         """
-        resp, error, message = self.get_model_training_logs()
-        training_logs = resp["data"]
+        import matplotlib.pyplot as plt
+        import seaborn as sns
 
+        resp, _, _ = self.get_model_training_logs()
+        training_logs = resp["data"]
         epochs = []
         metrics = {"train": {}, "val": {}}
         metrics_names = set()
-
-        # Parse metrics data from logs
         for epoch_data in training_logs:
             epochs.append(epoch_data["epoch"])
             for detail in epoch_data["epochDetails"]:
                 metric_name = detail["metricName"]
                 metric_value = detail["metricValue"]
                 split_type = detail["splitType"]
-
                 if "loss" not in metric_name:
                     if split_type not in metrics:
                         metrics[split_type] = []
@@ -708,30 +690,32 @@ class Model:
                         metrics[split_type][metric_name] = []
                     metrics[split_type][metric_name].append(metric_value)
                     metrics_names.add(metric_name)
-
         metrics_names = list(metrics_names)
         num_graphs = len(metrics_names)
-
-        # Set plot style
         sns.set(style="whitegrid")
         fig, axs = plt.subplots(num_graphs, 1, figsize=(12, 18))
-
-        # Plot each metric
-        for metric_index, metric_name in enumerate(metrics_names):
-            for split_type, split_metrics in metrics.items():
+        for (
+            metric_index,
+            metric_name,
+        ) in enumerate(metrics_names):
+            for (
+                split_type,
+                split_metrics,
+            ) in metrics.items():
                 if metric_name in metrics[split_type]:
                     axs[metric_index].plot(
                         epochs,
                         split_metrics[metric_name],
                         label=f"{split_type} {metric_name}",
                     )
-
             axs[metric_index].set_xlabel("Epoch", fontsize=14)
             axs[metric_index].set_ylabel(metric_name, fontsize=14)
             axs[metric_index].legend(fontsize=12)
-            axs[metric_index].set_title(f"{metric_name} over Epochs", fontsize=16)
+            axs[metric_index].set_title(
+                f"{metric_name} over Epochs",
+                fontsize=16,
+            )
             axs[metric_index].grid(True)
-
         plt.tight_layout()
         plt.show()
 
